@@ -1,6 +1,6 @@
 deg2dms = function(deg, type='mat', sep=':', digits=2){
 if(any(deg< -90 | deg>90)){stop('All deg values should be -90<=deg<=90')}
-    temp = sign(deg)
+    deg_sign = sign(deg)
     deg = abs(deg)
     DEG = floor(deg)
     MIN = floor((deg - DEG) * 60)
@@ -14,12 +14,15 @@ if(any(deg< -90 | deg>90)){stop('All deg values should be -90<=deg<=90')}
     if(digits<0){width=9}
     if(digits==0){width=2}
     if(digits>0){width=digits+3}
+    SEC = abs(SEC)
+    MIN = abs(MIN)
+    DEG = abs(DEG)
     SEC = formatC(SEC, format = "f", width = width, flag = 0, digits = digits)
     MIN = formatC(MIN, format = "f", width = 2, flag = 0, digits = 0)
     DEG = formatC(DEG, format = "f", width = 2, flag = 0, digits = 0)
-    DEG[temp == -1] = paste("-", DEG[temp == -1], sep = "")
-    DEG[temp == 1] = paste("+", DEG[temp == 1], sep = "")
-    DEG[temp == 0] = paste("+", DEG[temp == 0], sep = "")
+    DEG[deg_sign == -1] = paste0("-", DEG[deg_sign == -1])
+    DEG[deg_sign == 1] = paste0("+", DEG[deg_sign == 1])
+    DEG[deg_sign == 0] = paste0("+", DEG[deg_sign == 0])
     if(type=='mat'){output = cbind(DEG, MIN, SEC)}
     if(type=='cat' & sep!='DMS' & sep!='dms'){output=apply(cbind(DEG, MIN, SEC),1,paste,collapse=sep)}
     if(type=='cat' & sep=='DMS'){output=paste(DEG,'D',MIN,'M',SEC,'S',sep='')}
